package com.danitheskunk.skunkworks;

import com.danitheskunk.skunkworks.gfx.IRenderContext;
import com.danitheskunk.skunkworks.gfx.font.IFont;
import com.danitheskunk.skunkworks.nodes.Node;

public abstract class BaseGame {
	protected Engine engine;
	protected IWindow window;
	protected IFont debugFont;
	protected Node rootNode;

	public BaseGame(Vec2i windowSize, String windowTitle) {
		this.engine = new Engine();
		this.window = engine.openWindow(windowSize, windowTitle);
		//todo: load from .jar
		this.debugFont = window.loadFontTileset("fonts/ega-8x14.png");
		this.rootNode = new Node();
		init();
	}

	public void run() {
		while(!window.shouldClose()) {
			window.tick();
			//todo: frame rate control
			update(1000.0 / 60.0);
			var rc = window.renderStart();
			renderPre(rc);
			rootNode.render(rc);
			render(rc);
			window.renderFinish(rc);
		}
	}

	protected void init() {

	}

	protected void renderPre(IRenderContext rc) {

	}

	protected void render(IRenderContext rc) {
		//rc.drawString(new Vec2i(8, 8), "Welcome to Skunkworks, please
		// overide the render method to get started", debugFont, Color
		// .LIGHT_GRAY);
	}

	protected void update(double delta) {

	}
}
